10 DEPTH=0
20 GOSUB 1000
30 PRINT "Maximum depth reached:", DEPTH
40 END
1000 DEPTH=DEPTH+1
1001 PRINT "Depth:", DEPTH
1002 GOSUB 1010
1003 RETURN
1010 DEPTH=DEPTH+1
1011 PRINT "Depth:", DEPTH
1012 GOSUB 1020
1013 RETURN
1020 DEPTH=DEPTH+1
1021 PRINT "Depth:", DEPTH
1022 GOSUB 1030
1023 RETURN
1030 DEPTH=DEPTH+1
1031 PRINT "Depth:", DEPTH
1032 GOSUB 1040
1033 RETURN
1040 DEPTH=DEPTH+1
1041 PRINT "Depth:", DEPTH
1042 GOSUB 1050
1043 RETURN
1050 DEPTH=DEPTH+1
1051 PRINT "Depth:", DEPTH
1052 GOSUB 1060
1053 RETURN
1060 DEPTH=DEPTH+1
1061 PRINT "Depth:", DEPTH
1062 GOSUB 1070
1063 RETURN
1070 DEPTH=DEPTH+1
1071 PRINT "Depth:", DEPTH
1072 GOSUB 1080
1073 RETURN
1080 DEPTH=DEPTH+1
1081 PRINT "Depth:", DEPTH
1082 GOSUB 1090
1083 RETURN
1090 DEPTH=DEPTH+1
1091 PRINT "Depth:", DEPTH
1092 GOSUB 1100
1093 RETURN
1100 DEPTH=DEPTH+1
1101 PRINT "Depth:", DEPTH
1102 GOSUB 1110
1103 RETURN
1110 DEPTH=DEPTH+1
1111 PRINT "Depth:", DEPTH
1112 GOSUB 1120
1113 RETURN
1120 DEPTH=DEPTH+1
1121 PRINT "Depth:", DEPTH
1122 GOSUB 1130
1123 RETURN
1130 DEPTH=DEPTH+1
1131 PRINT "Depth:", DEPTH
1132 GOSUB 1140
1133 RETURN
1140 DEPTH=DEPTH+1
1141 PRINT "Depth:", DEPTH
1142 GOSUB 1150
1143 RETURN
1150 DEPTH=DEPTH+1
1151 PRINT "Depth:", DEPTH
1152 GOSUB 1160
1153 RETURN
1160 DEPTH=DEPTH+1
1161 PRINT "Depth:", DEPTH
1162 GOSUB 1170
1163 RETURN
1170 DEPTH=DEPTH+1
1171 PRINT "Depth:", DEPTH
1172 GOSUB 1180
1173 RETURN
1180 DEPTH=DEPTH+1
1181 PRINT "Depth:", DEPTH
1182 GOSUB 1190
1183 RETURN
1190 DEPTH=DEPTH+1
1191 PRINT "Depth:", DEPTH
1192 GOSUB 1200
1193 RETURN
1200 DEPTH=DEPTH+1
1201 PRINT "Depth:", DEPTH
1202 GOSUB 1210
1203 RETURN
1210 DEPTH=DEPTH+1
1211 PRINT "Depth:", DEPTH
1212 GOSUB 1220
1213 RETURN
1220 DEPTH=DEPTH+1
1221 PRINT "Depth:", DEPTH
1222 GOSUB 1230
1223 RETURN
1230 DEPTH=DEPTH+1
1231 PRINT "Depth:", DEPTH
1232 GOSUB 1240
1233 RETURN
1240 DEPTH=DEPTH+1
1241 PRINT "Depth:", DEPTH
1242 GOSUB 1250
1243 RETURN
1250 DEPTH=DEPTH+1
1251 PRINT "Depth:", DEPTH
1252 GOSUB 1260
1253 RETURN
1260 DEPTH=DEPTH+1
1261 PRINT "Depth:", DEPTH
1262 GOSUB 1270
1263 RETURN
1270 DEPTH=DEPTH+1
1271 PRINT "Depth:", DEPTH
1272 GOSUB 1280
1273 RETURN
1280 DEPTH=DEPTH+1
1281 PRINT "Depth:", DEPTH
1282 GOSUB 1290
1283 RETURN
1290 DEPTH=DEPTH+1
1291 PRINT "Depth:", DEPTH
1292 GOSUB 1300
1293 RETURN
1300 DEPTH=DEPTH+1
1301 PRINT "Depth:", DEPTH
1302 GOSUB 1310
1303 RETURN
1310 DEPTH=DEPTH+1
1311 PRINT "Depth:", DEPTH
1312 GOSUB 1320
1313 RETURN
1320 DEPTH=DEPTH+1
1321 PRINT "Depth:", DEPTH
1322 GOSUB 1330
1323 RETURN
1330 DEPTH=DEPTH+1
1331 PRINT "Depth:", DEPTH
1332 GOSUB 1340
1333 RETURN
1340 DEPTH=DEPTH+1
1341 PRINT "Depth:", DEPTH
1342 GOSUB 1350
1343 RETURN
1350 DEPTH=DEPTH+1
1351 PRINT "Depth:", DEPTH
1352 GOSUB 1360
1353 RETURN
1360 DEPTH=DEPTH+1
1361 PRINT "Depth:", DEPTH
1362 GOSUB 1370
1363 RETURN
1370 DEPTH=DEPTH+1
1371 PRINT "Depth:", DEPTH
1372 GOSUB 1380
1373 RETURN
1380 DEPTH=DEPTH+1
1381 PRINT "Depth:", DEPTH
1382 GOSUB 1390
1383 RETURN
1390 DEPTH=DEPTH+1
1391 PRINT "Depth:", DEPTH
1392 GOSUB 1400
1393 RETURN
1400 DEPTH=DEPTH+1
1401 PRINT "Depth:", DEPTH
1402 GOSUB 1410
1403 RETURN
1410 DEPTH=DEPTH+1
1411 PRINT "Depth:", DEPTH
1412 GOSUB 1420
1413 RETURN
1420 DEPTH=DEPTH+1
1421 PRINT "Depth:", DEPTH
1422 GOSUB 1430
1423 RETURN
1430 DEPTH=DEPTH+1
1431 PRINT "Depth:", DEPTH
1432 GOSUB 1440
1433 RETURN
1440 DEPTH=DEPTH+1
1441 PRINT "Depth:", DEPTH
1442 GOSUB 1450
1443 RETURN
1450 DEPTH=DEPTH+1
1451 PRINT "Depth:", DEPTH
1452 GOSUB 1460
1453 RETURN
1460 DEPTH=DEPTH+1
1461 PRINT "Depth:", DEPTH
1462 GOSUB 1470
1463 RETURN
1470 DEPTH=DEPTH+1
1471 PRINT "Depth:", DEPTH
1472 GOSUB 1480
1473 RETURN
1480 DEPTH=DEPTH+1
1481 PRINT "Depth:", DEPTH
1482 GOSUB 1490
1483 RETURN
1490 DEPTH=DEPTH+1
1491 PRINT "Depth:", DEPTH
1492 GOSUB 1500
1493 RETURN
1500 DEPTH=DEPTH+1
1501 PRINT "Depth:", DEPTH
1502 GOSUB 1510
1503 RETURN
1510 DEPTH=DEPTH+1
1511 PRINT "Depth:", DEPTH
1512 GOSUB 1520
1513 RETURN
1520 DEPTH=DEPTH+1
1521 PRINT "Depth:", DEPTH
1522 GOSUB 1530
1523 RETURN
1530 DEPTH=DEPTH+1
1531 PRINT "Depth:", DEPTH
1532 GOSUB 1540
1533 RETURN
1540 DEPTH=DEPTH+1
1541 PRINT "Depth:", DEPTH
1542 GOSUB 1550
1543 RETURN
1550 DEPTH=DEPTH+1
1551 PRINT "Depth:", DEPTH
1552 GOSUB 1560
1553 RETURN
1560 DEPTH=DEPTH+1
1561 PRINT "Depth:", DEPTH
1562 GOSUB 1570
1563 RETURN
1570 DEPTH=DEPTH+1
1571 PRINT "Depth:", DEPTH
1572 GOSUB 1580
1573 RETURN
1580 DEPTH=DEPTH+1
1581 PRINT "Depth:", DEPTH
1582 GOSUB 1590
1583 RETURN
1590 DEPTH=DEPTH+1
1591 PRINT "Depth:", DEPTH
1592 GOSUB 1600
1593 RETURN
1600 DEPTH=DEPTH+1
1601 PRINT "Depth:", DEPTH
1602 GOSUB 1610
1603 RETURN
1610 DEPTH=DEPTH+1
1611 PRINT "Depth:", DEPTH
1612 GOSUB 1620
1613 RETURN
1620 DEPTH=DEPTH+1
1621 PRINT "Depth:", DEPTH
1622 GOSUB 1630
1623 RETURN
1630 DEPTH=DEPTH+1
1631 PRINT "Depth:", DEPTH
1632 GOSUB 1640
1633 RETURN
1640 DEPTH=DEPTH+1
1641 PRINT "Depth:", DEPTH
1642 GOSUB 1650
1643 RETURN
1650 DEPTH=DEPTH+1
1651 PRINT "Depth:", DEPTH
1652 GOSUB 1660
1653 RETURN
1660 DEPTH=DEPTH+1
1661 PRINT "Depth:", DEPTH
1662 GOSUB 1670
1663 RETURN
1670 DEPTH=DEPTH+1
1671 PRINT "Depth:", DEPTH
1672 GOSUB 1680
1673 RETURN
1680 DEPTH=DEPTH+1
1681 PRINT "Depth:", DEPTH
1682 GOSUB 1690
1683 RETURN
1690 DEPTH=DEPTH+1
1691 PRINT "Depth:", DEPTH
1692 GOSUB 1700
1693 RETURN
1700 DEPTH=DEPTH+1
1701 PRINT "Depth:", DEPTH
1702 GOSUB 1710
1703 RETURN
1710 DEPTH=DEPTH+1
1711 PRINT "Depth:", DEPTH
1712 GOSUB 1720
1713 RETURN
1720 DEPTH=DEPTH+1
1721 PRINT "Depth:", DEPTH
1722 GOSUB 1730
1723 RETURN
1730 DEPTH=DEPTH+1
1731 PRINT "Depth:", DEPTH
1732 GOSUB 1740
1733 RETURN
1740 DEPTH=DEPTH+1
1741 PRINT "Depth:", DEPTH
1742 GOSUB 1750
1743 RETURN
1750 DEPTH=DEPTH+1
1751 PRINT "Depth:", DEPTH
1752 GOSUB 1760
1753 RETURN
1760 DEPTH=DEPTH+1
1761 PRINT "Depth:", DEPTH
1762 GOSUB 1770
1763 RETURN
1770 DEPTH=DEPTH+1
1771 PRINT "Depth:", DEPTH
1772 GOSUB 1780
1773 RETURN
1780 DEPTH=DEPTH+1
1781 PRINT "Depth:", DEPTH
1782 GOSUB 1790
1783 RETURN
1790 DEPTH=DEPTH+1
1791 PRINT "Depth:", DEPTH
1792 GOSUB 1800
1793 RETURN
1800 DEPTH=DEPTH+1
1801 PRINT "Depth:", DEPTH
1802 GOSUB 1810
1803 RETURN
1810 DEPTH=DEPTH+1
1811 PRINT "Depth:", DEPTH
1812 GOSUB 1820
1813 RETURN
1820 DEPTH=DEPTH+1
1821 PRINT "Depth:", DEPTH
1822 GOSUB 1830
1823 RETURN
1830 DEPTH=DEPTH+1
1831 PRINT "Depth:", DEPTH
1832 GOSUB 1840
1833 RETURN
1840 DEPTH=DEPTH+1
1841 PRINT "Depth:", DEPTH
1842 GOSUB 1850
1843 RETURN
1850 DEPTH=DEPTH+1
1851 PRINT "Depth:", DEPTH
1852 GOSUB 1860
1853 RETURN
1860 DEPTH=DEPTH+1
1861 PRINT "Depth:", DEPTH
1862 GOSUB 1870
1863 RETURN
1870 DEPTH=DEPTH+1
1871 PRINT "Depth:", DEPTH
1872 GOSUB 1880
1873 RETURN
1880 DEPTH=DEPTH+1
1881 PRINT "Depth:", DEPTH
1882 GOSUB 1890
1883 RETURN
1890 DEPTH=DEPTH+1
1891 PRINT "Depth:", DEPTH
1892 GOSUB 1900
1893 RETURN
1900 DEPTH=DEPTH+1
1901 PRINT "Depth:", DEPTH
1902 GOSUB 1910
1903 RETURN
1910 DEPTH=DEPTH+1
1911 PRINT "Depth:", DEPTH
1912 GOSUB 1920
1913 RETURN
1920 DEPTH=DEPTH+1
1921 PRINT "Depth:", DEPTH
1922 GOSUB 1930
1923 RETURN
1930 DEPTH=DEPTH+1
1931 PRINT "Depth:", DEPTH
1932 GOSUB 1940
1933 RETURN
1940 DEPTH=DEPTH+1
1941 PRINT "Depth:", DEPTH
1942 GOSUB 1950
1943 RETURN
1950 DEPTH=DEPTH+1
1951 PRINT "Depth:", DEPTH
1952 GOSUB 1960
1953 RETURN
1960 DEPTH=DEPTH+1
1961 PRINT "Depth:", DEPTH
1962 GOSUB 1970
1963 RETURN
1970 DEPTH=DEPTH+1
1971 PRINT "Depth:", DEPTH
1972 GOSUB 1980
1973 RETURN
1980 DEPTH=DEPTH+1
1981 PRINT "Depth:", DEPTH
1982 GOSUB 1990
1983 RETURN
1990 DEPTH=DEPTH+1
1991 PRINT "Depth:", DEPTH
1993 RETURN